@@ -2,7 +2,7 @@ use strict;
 use warnings;
 use feature qw( say );
 package Dist::Zilla::PluginBundle::Author::OALDERS;
-$Dist::Zilla::PluginBundle::Author::OALDERS::VERSION = '0.000002';
+$Dist::Zilla::PluginBundle::Author::OALDERS::VERSION = '0.000003';
 use Moose;
 use List::AllUtils qw( first );
 use Types::Path::Tiny qw( Path );
@@ -36,7 +36,7 @@ sub configure {
     my $readme      = 'README.md';
     my @dirty_files = ( 'dist.ini', 'Changes', $readme );
     my @from_build  = qw(INSTALL LICENSE META.json);
-    my @copy        = ( 'cpanfile', $readme );
+    my @copy        = ( 'cpanfile', 'Makefile.PL', $readme );
 
     # Must come before Git::Commit
     $self->add_plugins('NextRelease');
@@ -131,7 +131,7 @@ Dist::Zilla::PluginBundle::Author::OALDERS - A plugin bundle for distributions b
 
 =head1 VERSION
 
-version 0.000002
+version 0.000003
 
 =head2 configure
 
